@@ -225,6 +225,7 @@ const char *const sit_bit_names[] = {
 /* Protocol IDs (RFC 2407 "IPsec DOI" section 4.4.1) */
 
 static const char *const protocol_name[] = {
+    	"PROTO_RESERVED",
 	"PROTO_ISAKMP",
 	"PROTO_IPSEC_AH",
 	"PROTO_IPSEC_ESP",
@@ -232,7 +233,21 @@ static const char *const protocol_name[] = {
     };
 
 enum_names protocol_names =
-    { PROTO_ISAKMP, PROTO_IPCOMP, protocol_name, NULL };
+    { PROTO_RESERVED, PROTO_IPCOMP, protocol_name, NULL };
+
+static const char *const ikev2_protocol_name[] = {
+    	"PROTO_v2_RESERVED"
+	"PROTO_v2_IKE",
+	"PROTO_v2_AH",
+	"PROTO_v2_ESP",
+    };
+
+enum_names ikev2_protocol_names =
+    { 0, PROTO_IPSEC_ESP, ikev2_protocol_name, NULL };
+
+
+
+
 
 /* IPsec ISAKMP transform values */
 
@@ -340,8 +355,9 @@ static const char *const cert_type_name[] = {
 enum_names cert_type_names =
     { CERT_NONE, CERT_X509_ATTRIBUTE, cert_type_name, NULL };
 
-/* Certificate type values RFC 4306 3.6*/
-
+/* Certificate type values RFC 4306 3.6 */
+/* TBD AA don't know how to add v2 sepecific ones, now it is mix of v1 & v2 */
+ 
 static const char *const ikev2_cert_type_name[] = {
         "CERT_RESERVED",
         "CERT_PKCS7_WRAPPED_X509",
@@ -365,7 +381,7 @@ static const char *const ikev2_cert_type_name[] = {
 };
 
 enum_names ikev2_cert_type_names =
-    { CERT_NONE, CERT_X509_ATTRIBUTE, ikev2_cert_type_name, NULL };
+    { CERT_NONE, CERT_RAW_RSA, ikev2_cert_type_name, NULL };
 
 /*
  * certificate request payload policy
@@ -839,6 +855,13 @@ enum_names ipsec_notification_names =
     { IPSEC_RESPONDER_LIFETIME, IPSEC_INITIAL_CONTACT,
 	ipsec_notification_name, &notification_status_names };
 
+static const char *ikev2_notify_name[] = {
+	   "v2N_RESERVED",
+	   "v2N_UNSUPPORTED_CRITICAL_PAYLOAD",
+ 	}; 
+
+enum_names ikev2_notify_names = 
+    { 0, 1, ikev2_notify_name, NULL};
 /* MODECFG */
 /*
  * From draft-dukes-ike-mode-cfg
