@@ -13,11 +13,10 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: ipsec_tunnel.h,v 1.33 2005-06-04 16:06:05 mcr Exp $
+ * RCSID $Id: ipsec_tunnel.h,v 1.33 2005/06/04 16:06:05 mcr Exp $
  */
 
 
-#ifdef NET_21
 # define DEV_QUEUE_XMIT(skb, device, pri) {\
 	skb->dev = device; \
 	neigh_compat_output(skb); \
@@ -27,22 +26,9 @@
 	icmp_send(skb_in, type, code, htonl(info))
 # define IP_SEND(skb, dev) \
 	ip_send(skb);
-#else /* NET_21 */
-# define DEV_QUEUE_XMIT(skb, device, pri) {\
-	dev_queue_xmit(skb, device, pri); \
- }
-# define ICMP_SEND(skb_in, type, code, info, dev) \
-	icmp_send(skb_in, type, code, info, dev)
-# define IP_SEND(skb, dev) \
-	if(ntohs(iph->tot_len) > physmtu) { \
-		ip_fragment(NULL, skb, dev, 0); \
-		ipsec_kfree_skb(skb); \
-	} else { \
-		dev_queue_xmit(skb, dev, SOPRI_NORMAL); \
-	}
-#endif /* NET_21 */
 
 
+#if defined(KLIPS)
 /*
  * Heavily based on drivers/net/new_tunnel.c.  Lots
  * of ideas also taken from the 2.1.x version of drivers/net/shaper.c
@@ -61,6 +47,8 @@ struct ipsectunnelconf
 #define IPSEC_SET_DEV	(SIOCDEVPRIVATE)
 #define IPSEC_DEL_DEV	(SIOCDEVPRIVATE + 1)
 #define IPSEC_CLR_DEV	(SIOCDEVPRIVATE + 2)
+#define IPSEC_UDP_ENCAP_CONVERT	(SIOCDEVPRIVATE + 3)
+#endif
 
 #ifdef __KERNEL__
 #include <linux/version.h>
@@ -128,9 +116,12 @@ extern int sysctl_ipsec_debug_verbose;
 #define DB_TN_ENCAP     0x0200
 #endif /* CONFIG_KLIPS_DEBUG */
 
+// manage ipsec xmit state objects
+extern int ipsec_xmit_state_cache_init (void);
+extern void ipsec_xmit_state_cache_cleanup (void);
 /*
  * $Log: ipsec_tunnel.h,v $
- * Revision 1.33  2005-06-04 16:06:05  mcr
+ * Revision 1.33  2005/06/04 16:06:05  mcr
  * 	better patch for nat-t rcv-device code.
  *
  * Revision 1.32  2005/05/21 03:18:35  mcr
