@@ -1,5 +1,7 @@
 /*
  * IPCOMP zlib interface code.
+ * implementation of RFC 3173.
+ *
  * Copyright (C) 2000  Svenning Soerensen <svenning@post5.tele.dk>
  * Copyright (C) 2000, 2001  Richard Guy Briggs <rgb@conscoop.ottawa.on.ca>
  * 
@@ -14,8 +16,6 @@
  * for more details.
  */
 
-char ipcomp_c_version[] = "RCSID $Id: ipcomp.c,v 1.41.2.8 2007-10-30 21:33:40 paul Exp $";
-
 /* SSS */
 
 #ifndef AUTOCONF_INCLUDED
@@ -51,6 +51,7 @@ char ipcomp_c_version[] = "RCSID $Id: ipcomp.c,v 1.41.2.8 2007-10-30 21:33:40 pa
 
 #include <net/ip.h>
 
+#include "openswan/ipsec_kern24.h"
 #include "openswan/radij.h"
 #include "openswan/ipsec_encap.h"
 #include "openswan/ipsec_sa.h"
@@ -63,7 +64,7 @@ char ipcomp_c_version[] = "RCSID $Id: ipcomp.c,v 1.41.2.8 2007-10-30 21:33:40 pa
 #include "zlib/zlib.h"
 #include "zlib/zutil.h"
 
-#include <pfkeyv2.h> /* SADB_X_CALG_DEFLATE */
+#include <openswan/pfkeyv2.h> /* SADB_X_CALG_DEFLATE */
 
 #ifdef CONFIG_KLIPS_DEBUG
 int sysctl_ipsec_debug_ipcomp = 0;
@@ -679,7 +680,7 @@ struct sk_buff *skb_copy_ipcomp(struct sk_buff *skb, int data_growth, int gfp_ma
 #endif /* NETDEV_23 */
 	n->ip_summed=0;
 #ifdef HAVE_TSTAMP
-        n->tstamp = skb->tstamp;
+	n->tstamp = skb->tstamp;
 #else
         n->stamp=skb->stamp;
 #endif
