@@ -18,13 +18,12 @@
  * for more details.
  *
  */
-#ifndef AUTOCONF_INCLUDED
-#include <linux/config.h>
-#endif
-#include <linux/version.h>
-
 #define __NO_VERSION__
+
+#if defined (MODULE)
 #include <linux/module.h>
+#endif
+
 #include <linux/kernel.h> /* printk() */
 
 #include <linux/netdevice.h>   /* struct device, and other headers */
