@@ -13,7 +13,6 @@
  * for more details.
  */
 
-char ipsec_ipcomp_c_version[] = "RCSID $Id: ipsec_ipcomp.c,v 1.5.2.3 2007-09-05 02:56:09 paul Exp $";
 #ifndef AUTOCONF_INCLUDED
 #include <linux/config.h>
 #endif
@@ -235,6 +234,7 @@ struct xform_functions ipcomp_xform_funcs[]={
 /* We probably don't want to install a pure IPCOMP protocol handler, but
    only want to handle IPCOMP if it is encapsulated inside an ESP payload
    (which is already handled) */
+#ifndef CONFIG_XFRM_ALTERNATE_STACK
 #ifdef CONFIG_KLIPS_IPCOMP
 struct inet_protocol comp_protocol =
 {
@@ -251,6 +251,7 @@ struct inet_protocol comp_protocol =
 #endif
 };
 #endif /* CONFIG_KLIPS_IPCOMP */
+#endif /* CONFIG_XFRM_ALTERNATE_STACK */
 #endif
 
 #endif /* CONFIG_KLIPS_IPCOMP */
