@@ -1,5 +1,6 @@
 /* Openswan NAT-Traversal
  * Copyright (C) 2002-2003 Mathieu Lafon - Arkoon Network Security
+ * Copyright (C) 2005 Michael Richardson <mcr@xelerance.com>
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -11,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: nat_traversal.h,v 1.4.8.3 2007-11-07 02:38:21 paul Exp $
+ * RCSID $Id: nat_traversal.h,v 1.5 2005/09/26 23:35:28 mcr Exp $
  */
 
 #ifndef _NAT_TRAVERSAL_H_
@@ -104,10 +105,11 @@ bool nat_traversal_add_natd(u_int8_t np, pb_stream *outs,
 /**
  * NAT-OA
  */
-void nat_traversal_natoa_lookup(struct msg_digest *md);
+struct hidden_variables;
+void nat_traversal_natoa_lookup(struct msg_digest *md , struct hidden_variables *hv);
 #ifndef PB_STREAM_UNDEFINED
 bool nat_traversal_add_natoa(u_int8_t np, pb_stream *outs,
-	struct state *st);
+			     struct state *st, bool initiator);
 #endif
 
 /**
@@ -127,6 +129,7 @@ extern int nat_traversal_espinudp_socket (int sk
  */
 #ifndef PB_STREAM_UNDEFINED
 bool nat_traversal_add_vid(u_int8_t np, pb_stream *outs);
+bool nat_traversal_insert_vid(u_int8_t np, pb_stream *outs);
 #endif
 u_int32_t nat_traversal_vid_to_method(unsigned short nat_t_vid);
 
