@@ -107,12 +107,27 @@ static struct db_attr otpsk1536des3md5[] = {
 	{ .type.oakley=OAKLEY_GROUP_DESCRIPTION, .val=OAKLEY_GROUP_MODP1536 },
 	};
 
+static struct db_attr otpsk2048des3md5[] = {
+	{ .type.oakley=OAKLEY_ENCRYPTION_ALGORITHM, .val=OAKLEY_3DES_CBC },
+	{ .type.oakley=OAKLEY_HASH_ALGORITHM, .val=OAKLEY_MD5 },
+	{ .type.oakley=OAKLEY_AUTHENTICATION_METHOD, .val=OAKLEY_PRESHARED_KEY },
+	{ .type.oakley=OAKLEY_GROUP_DESCRIPTION, .val=OAKLEY_GROUP_MODP2048 },
+	};
+
 static struct db_attr otpsk1536aesmd5[] = {
 	{ .type.oakley=OAKLEY_ENCRYPTION_ALGORITHM, .val=OAKLEY_AES_CBC },
 	{ .type.oakley=OAKLEY_HASH_ALGORITHM, .val=OAKLEY_MD5 },
 	{ .type.oakley=OAKLEY_AUTHENTICATION_METHOD, .val=OAKLEY_PRESHARED_KEY },
 	{ .type.oakley=OAKLEY_GROUP_DESCRIPTION, .val=OAKLEY_GROUP_MODP1536 },
-	};
+	}; 
+
+static struct db_attr otpsk2048aesmd5[] = {
+	{ .type.oakley=OAKLEY_ENCRYPTION_ALGORITHM, .val=OAKLEY_AES_CBC },
+	{ .type.oakley=OAKLEY_HASH_ALGORITHM, .val=OAKLEY_MD5 },
+	{ .type.oakley=OAKLEY_AUTHENTICATION_METHOD, .val=OAKLEY_PRESHARED_KEY },
+	{ .type.oakley=OAKLEY_GROUP_DESCRIPTION, .val=OAKLEY_GROUP_MODP2048 },
+	}; 
+
 
 static struct db_attr otpsk1536aessha1[] = {
 	{ .type.oakley=OAKLEY_ENCRYPTION_ALGORITHM, .val=OAKLEY_AES_CBC },
@@ -121,6 +136,13 @@ static struct db_attr otpsk1536aessha1[] = {
 	{ .type.oakley=OAKLEY_GROUP_DESCRIPTION, .val=OAKLEY_GROUP_MODP1536 },
 	};
 
+static struct db_attr otpsk2048aessha1[] = {
+	{ .type.oakley=OAKLEY_ENCRYPTION_ALGORITHM, .val=OAKLEY_AES_CBC },
+	{ .type.oakley=OAKLEY_HASH_ALGORITHM, .val=OAKLEY_SHA1 },
+	{ .type.oakley=OAKLEY_AUTHENTICATION_METHOD, .val=OAKLEY_PRESHARED_KEY },
+	{ .type.oakley=OAKLEY_GROUP_DESCRIPTION, .val=OAKLEY_GROUP_MODP2048 },
+	};
+
 static struct db_attr otpsk1024des3sha1[] = {
 	{ .type.oakley=OAKLEY_ENCRYPTION_ALGORITHM, .val=OAKLEY_3DES_CBC },
 	{ .type.oakley=OAKLEY_HASH_ALGORITHM, .val=OAKLEY_SHA },
@@ -135,6 +157,13 @@ static struct db_attr otpsk1536des3sha1[] = {
 	{ .type.oakley=OAKLEY_GROUP_DESCRIPTION, .val=OAKLEY_GROUP_MODP1536 },
 	};
 
+static struct db_attr otpsk2048des3sha1[] = {
+	{ .type.oakley=OAKLEY_ENCRYPTION_ALGORITHM, .val=OAKLEY_3DES_CBC },
+	{ .type.oakley=OAKLEY_HASH_ALGORITHM, .val=OAKLEY_SHA },
+	{ .type.oakley=OAKLEY_AUTHENTICATION_METHOD, .val=OAKLEY_PRESHARED_KEY },
+	{ .type.oakley=OAKLEY_GROUP_DESCRIPTION, .val=OAKLEY_GROUP_MODP2048 },
+	};
+
 /* arrays of attributes for transforms, preshared key, Xauth version */
 
 #ifdef XAUTH
@@ -231,6 +260,13 @@ static struct db_attr otrsasig1536aesmd5[] = {
 	{ .type.oakley=OAKLEY_GROUP_DESCRIPTION, .val=OAKLEY_GROUP_MODP1536 },
 	};
 
+static struct db_attr otrsasig2048aesmd5[] = {
+	{ .type.oakley=OAKLEY_ENCRYPTION_ALGORITHM, .val=OAKLEY_AES_CBC },
+	{ .type.oakley=OAKLEY_HASH_ALGORITHM, .val=OAKLEY_MD5 },
+	{ .type.oakley=OAKLEY_AUTHENTICATION_METHOD, .val=OAKLEY_RSA_SIG },
+	{ .type.oakley=OAKLEY_GROUP_DESCRIPTION, .val=OAKLEY_GROUP_MODP2048 },
+	};
+
 static struct db_attr otrsasig1536aessha1[] = {
 	{ .type.oakley=OAKLEY_ENCRYPTION_ALGORITHM, .val=OAKLEY_AES_CBC },
 	{ .type.oakley=OAKLEY_HASH_ALGORITHM, .val=OAKLEY_SHA1 },
@@ -238,6 +274,13 @@ static struct db_attr otrsasig1536aessha1[] = {
 	{ .type.oakley=OAKLEY_GROUP_DESCRIPTION, .val=OAKLEY_GROUP_MODP1536 },
 	};
 
+static struct db_attr otrsasig2048aessha1[] = {
+	{ .type.oakley=OAKLEY_ENCRYPTION_ALGORITHM, .val=OAKLEY_AES_CBC },
+	{ .type.oakley=OAKLEY_HASH_ALGORITHM, .val=OAKLEY_SHA1 },
+	{ .type.oakley=OAKLEY_AUTHENTICATION_METHOD, .val=OAKLEY_RSA_SIG },
+	{ .type.oakley=OAKLEY_GROUP_DESCRIPTION, .val=OAKLEY_GROUP_MODP2048 },
+	};
+
 static struct db_attr otrsasig1024des3md5[] = {
 	{ .type.oakley=OAKLEY_ENCRYPTION_ALGORITHM, .val=OAKLEY_3DES_CBC },
 	{ .type.oakley=OAKLEY_HASH_ALGORITHM, .val=OAKLEY_MD5 },
@@ -252,6 +295,13 @@ static struct db_attr otrsasig1536des3md5[] = {
 	{ .type.oakley=OAKLEY_GROUP_DESCRIPTION, .val=OAKLEY_GROUP_MODP1536 },
 	};
 
+static struct db_attr otrsasig2048des3md5[] = {
+	{ .type.oakley=OAKLEY_ENCRYPTION_ALGORITHM, .val=OAKLEY_3DES_CBC },
+	{ .type.oakley=OAKLEY_HASH_ALGORITHM, .val=OAKLEY_MD5 },
+	{ .type.oakley=OAKLEY_AUTHENTICATION_METHOD, .val=OAKLEY_RSA_SIG },
+	{ .type.oakley=OAKLEY_GROUP_DESCRIPTION, .val=OAKLEY_GROUP_MODP2048 },
+	};
+
 static struct db_attr otrsasig1024des3sha1[] = {
 	{ .type.oakley=OAKLEY_ENCRYPTION_ALGORITHM, .val=OAKLEY_3DES_CBC },
 	{ .type.oakley=OAKLEY_HASH_ALGORITHM, .val=OAKLEY_SHA },
@@ -266,6 +316,13 @@ static struct db_attr otrsasig1536des3sha1[] = {
 	{ .type.oakley=OAKLEY_GROUP_DESCRIPTION, .val=OAKLEY_GROUP_MODP1536 },
 	};
 
+static struct db_attr otrsasig2048des3sha1[] = {
+	{ .type.oakley=OAKLEY_ENCRYPTION_ALGORITHM, .val=OAKLEY_3DES_CBC },
+	{ .type.oakley=OAKLEY_HASH_ALGORITHM, .val=OAKLEY_SHA },
+	{ .type.oakley=OAKLEY_AUTHENTICATION_METHOD, .val=OAKLEY_RSA_SIG },
+	{ .type.oakley=OAKLEY_GROUP_DESCRIPTION, .val=OAKLEY_GROUP_MODP2048 },
+	};
+
 #ifdef XAUTH
 /* arrays of attributes for transforms, RSA signatures, with/Xauth */
 /* xauth c is when Initiator will be the xauth client */
@@ -385,6 +442,10 @@ static struct db_trans oakley_trans_psk[] = {
 	{ AD_TR(KEY_IKE,otpsk1536des3md5) },
 	{ AD_TR(KEY_IKE,otpsk1024des3sha1) },
 	{ AD_TR(KEY_IKE,otpsk1024des3md5) },
+	{ AD_TR(KEY_IKE,otpsk2048aessha1) },
+	{ AD_TR(KEY_IKE,otpsk2048aesmd5) },
+	{ AD_TR(KEY_IKE,otpsk2048des3sha1) },
+	{ AD_TR(KEY_IKE,otpsk2048des3md5) },
     };
 
 #ifdef XAUTH
@@ -407,6 +468,10 @@ static struct db_trans oakley_trans_psk_xauths[] = {
 #endif
 
 static struct db_trans oakley_trans_rsasig[] = {
+	{ AD_TR(KEY_IKE,otrsasig2048aessha1) },
+	{ AD_TR(KEY_IKE,otrsasig2048aesmd5) },
+	{ AD_TR(KEY_IKE,otrsasig2048des3sha1) },
+	{ AD_TR(KEY_IKE,otrsasig2048des3md5) },
 	{ AD_TR(KEY_IKE,otrsasig1536aessha1) },
 	{ AD_TR(KEY_IKE,otrsasig1536aesmd5) },
 	{ AD_TR(KEY_IKE,otrsasig1536des3sha1) },
