@@ -152,10 +152,12 @@ generate_msgid(struct state *isakmp_sa)
 static struct state *statetable[STATE_TABLE_SIZE];
 
 static struct state **
-state_hash(const u_char *icookie, const u_char *rcookie)
+state_hash(const u_char *icookie, const u_char *rcookie, int *bucketp)
 {
     u_int i = 0, j;
 
+    if(bucketp) *bucketp = -1;
+
     DBG(DBG_RAW | DBG_CONTROL,
 	DBG_dump("ICOOKIE:", icookie, COOKIE_SIZE);
 	DBG_dump("RCOOKIE:", rcookie, COOKIE_SIZE));
@@ -168,6 +170,7 @@ state_hash(const u_char *icookie, const u_char *rcookie)
     i = i % STATE_TABLE_SIZE;
 
     DBG(DBG_CONTROL, DBG_log("state hash entry %d", i));
+    if(bucketp) *bucketp = i;
 
     return &statetable[i];
 }
@@ -191,8 +194,8 @@ new_state(void)
     anyaddr(AF_INET, &st->hidden_variables.st_nat_oa);
     anyaddr(AF_INET, &st->hidden_variables.st_natd);
 
-    DBG(DBG_CONTROL, DBG_log("creating state object #%lu at %p",
-	st->st_serialno, (void *) st));
+    DBG(DBG_CONTROL, DBG_log("creating state object #%lu at %p"
+			     , st->st_serialno, (void *) st));
     return st;
 }
 
@@ -238,10 +241,15 @@ state_with_serialno(so_serial_t sn)
 void
 insert_state(struct state *st)
 {
-    struct state **p = state_hash(st->st_icookie, st->st_rcookie);
+    int bucketno;
+    struct state **p = state_hash(st->st_icookie, st->st_rcookie, &bucketno);
 
     passert(st->st_hashchain_prev == NULL && st->st_hashchain_next == NULL);
 
+    DBG(DBG_CONTROL
+	, DBG_log("inserting state object #%lu on chain %u"
+		  , st->st_serialno, bucketno));
+
     if (*p != NULL)
     {
 	passert((*p)->st_hashchain_prev == NULL);
@@ -259,15 +267,56 @@ insert_state(struct state *st)
 	event_schedule(EVENT_SO_DISCARD, 0, st);
 }
 
+/*
+ * unlink a state object from the hash table that had a zero
+ * rcookie before, and rehash it into the right place
+ */
+void
+rehash_state(struct state *st)
+{
+    /* unlink from forward chain */
+    int bucketno = -1;
+    struct state **p = st->st_hashchain_prev == NULL
+	? state_hash(st->st_icookie, zero_cookie, &bucketno)
+	: &st->st_hashchain_prev->st_hashchain_next;
+
+    DBG(DBG_CONTROL
+	, DBG_log("rehashing state object #%lu, removed from chain %d"
+			     , st->st_serialno, bucketno));
+
+    /* unlink from forward chain */
+    passert(*p == st);
+    *p = st->st_hashchain_next;
+
+    /* unlink from backward chain */
+    if (st->st_hashchain_next != NULL)
+    {
+	passert(st->st_hashchain_next->st_hashchain_prev == st);
+	st->st_hashchain_next->st_hashchain_prev = st->st_hashchain_prev;
+    }
+
+    st->st_hashchain_next = st->st_hashchain_prev = NULL;
+
+    /* now, re-insert */
+    insert_state(st);
+}
+
 /* unlink a state object from the hash table, but don't free it
  */
 void
 unhash_state(struct state *st)
 {
     /* unlink from forward chain */
-    struct state **p = st->st_hashchain_prev == NULL
-	? state_hash(st->st_icookie, st->st_rcookie)
-	: &st->st_hashchain_prev->st_hashchain_next;
+    struct state **p;
+
+    if(st->st_hashchain_prev == NULL) {
+	p = state_hash(st->st_icookie, st->st_rcookie, NULL);
+	if(*p != st) {
+	    p = state_hash(st->st_icookie, zero_cookie, NULL);
+	}
+    } else {
+	p = &st->st_hashchain_prev->st_hashchain_next;
+    }
 
     /* unlink from forward chain */
     passert(*p == st);
@@ -797,7 +846,7 @@ find_state_ikev1(const u_char *icookie
 		 , const ip_address *peer UNUSED
 		 , msgid_t /*network order*/ msgid)
 {
-    struct state *st = *state_hash(icookie, rcookie);
+    struct state *st = *state_hash(icookie, rcookie, NULL);
 
     while (st != (struct state *) NULL)
     {
@@ -835,7 +884,7 @@ struct state *
 find_state_ikev2_parent(const u_char *icookie
 			, const u_char *rcookie)
 {
-    struct state *st = *state_hash(icookie, rcookie);
+    struct state *st = *state_hash(icookie, rcookie, NULL);
 
     while (st != (struct state *) NULL)
     {
@@ -863,6 +912,40 @@ find_state_ikev2_parent(const u_char *icookie
     return st;
 }
 
+/*
+ * Find a state object for an IKEv2 state, looking by icookie only.
+ * Note: only finds parent states.
+ */
+struct state *
+find_state_ikev2_parent_init(const u_char *icookie)
+{
+    struct state *st = *state_hash(icookie, zero_cookie, NULL);
+
+    while (st != (struct state *) NULL)
+    {
+	if (memcmp(icookie, st->st_icookie, COOKIE_SIZE) == 0
+	    && st->st_ikev2 == TRUE
+	    && st->st_clonedfrom == 0)
+	{
+	    DBG(DBG_CONTROL,
+		DBG_log("v2 peer and cookies match on #%ld"
+			, st->st_serialno));
+	    break;
+	}
+	st = st->st_hashchain_next;
+    }
+
+    DBG(DBG_CONTROL,
+	if (st == NULL)
+	    DBG_log("v2 state object not found");
+	else
+	    DBG_log("v2 state object #%lu found, in %s"
+		, st->st_serialno
+		, enum_show(&state_names, st->st_state)));
+
+    return st;
+}
+
 /*
  * Find a state object for an IKEv2 state, a response that includes a msgid.
  */
@@ -871,7 +954,7 @@ find_state_ikev2_child(const u_char *icookie
 		       , const u_char *rcookie
 		       , msgid_t msgid)
 {
-    struct state *st = *state_hash(icookie, rcookie);
+    struct state *st = *state_hash(icookie, rcookie, NULL);
 
     while (st != (struct state *) NULL)
     {
@@ -908,7 +991,7 @@ find_info_state(const u_char *icookie
 		, const ip_address *peer UNUSED
 		, msgid_t /*network order*/ msgid)
 {
-    struct state *st = *state_hash(icookie, rcookie);
+    struct state *st = *state_hash(icookie, rcookie, NULL);
 
     while (st != (struct state *) NULL)
     {
