@@ -4,8 +4,8 @@ TEST_TYPE=klipstest
 TESTNAME=west-drop-02
 TESTHOST=west
 EXITONEMPTY=--exitonempty
-PRIVINPUT=../inputs/ikeinit-japan-sunrise.pcap
-REFPUBOUTPUT=spi1-output.txt
+PRIV_INPUT=../inputs/ikeinit-japan-sunrise.pcap
+REF_PUB_OUTPUT=spi1-output.txt
 REF_CONSOLE_OUTPUT=spi1-console.txt
 REF26_CONSOLE_OUTPUT=spi1-console.txt
 REF_CONSOLE_FIXUPS="kern-list-fixups.sed nocr.sed"
