@@ -14,11 +14,19 @@
 #include "../../programs/pluto/connections.c"
 
 #include "whackmsgtestlib.c"
+#include "seam_x509.c"
 #include "seam_log.c"
 #include "seam_state.c"
+#include "seam_west.c"
 #include "seam_initiate.c"
+#include "seam_terminate.c"
 #include "seam_xauth.c"
 #include "seam_alg.c" 
+#include "seam_spdb.c"
+#include "seam_keys.c"
+#include "seam_exitlog.c"
+#include "seam_whack.c"
+#include "seam_kernel.c"
 
 main(int argc, char *argv[])
 {
@@ -29,6 +37,7 @@ main(int argc, char *argv[])
     EF_FREE_WIPES  =1;
 
     progname = argv[0];
+    leak_detective = 1;
 
     if(argc > 2 ) {
 	fprintf(stderr, "Usage: %s <whackrecord>\n", progname);
@@ -53,6 +62,6 @@ main(int argc, char *argv[])
  * Local Variables:
  * c-style: pluto
  * c-basic-offset: 4
- * compile-command: "make whackmsgtest"
+ * compile-command: "make TEST=whackmsgtest one"
  * End:
  */
